==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/bmp/skin_pb_vtruck.bmp.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_pb_vtruck.bmp"

unsigned char _mgir_bmp_skin_pb_vtruck_data[]={
	0x42,0x4D,0xA0,0x01,0x00,0x00,0x00,0x00,	0x00,0x00,0x36,0x00,0x00,0x00,0x28,0x00,
	0x00,0x00,0x0C,0x00,0x00,0x00,0x0A,0x00,	0x00,0x00,0x01,0x00,0x18,0x00,0x00,0x00,
	0x00,0x00,0x6A,0x01,0x00,0x00,0x12,0x0B,	0x00,0x00,0x12,0x0B,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x2D,0xA0,	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,
	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,
	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,
	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,
	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,
	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,
	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,
	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,
	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,
	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,
	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,
	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,
	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,
	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,
	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,
	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,
	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,
	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,
	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,
	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,
	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,
	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,
	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x00,0x00
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/bmp/skin_pb_vtruck.bmp.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_pb_vtruck.bmp"

const unsigned char _mgir_bmp_skin_pb_vtruck_data[]={
	0x42,0x4D,0xA0,0x01,0x00,0x00,0x00,0x00,	0x00,0x00,0x36,0x00,0x00,0x00,0x28,0x00,
	0x00,0x00,0x0C,0x00,0x00,0x00,0x0A,0x00,	0x00,0x00,0x01,0x00,0x18,0x00,0x00,0x00,
	0x00,0x00,0x6A,0x01,0x00,0x00,0x12,0x0B,	0x00,0x00,0x12,0x0B,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x2D,0xA0,	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,
	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,
	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,
	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,
	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,
	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,
	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,
	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,
	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,
	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,
	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,
	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,
	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,
	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,
	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,
	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,
	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,
	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,
	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x2D,0xA0,	0xE2,0x2C,0xA2,0xE4,0x2B,0xA4,0xE6,0x29,
	0xA6,0xE9,0x28,0xA9,0xEC,0x26,0xAB,0xEF,	0x25,0xAE,0xF3,0x23,0xB0,0xF6,0x22,0xB3,
	0xF9,0x21,0xB5,0xFB,0x20,0xB7,0xFD,0x1F,	0xB8,0xFF,0x2D,0xA0,0xE2,0x2C,0xA2,0xE4,
	0x2B,0xA4,0xE6,0x29,0xA6,0xE9,0x28,0xA9,	0xEC,0x26,0xAB,0xEF,0x25,0xAE,0xF3,0x23,
	0xB0,0xF6,0x22,0xB3,0xF9,0x21,0xB5,0xFB,	0x20,0xB7,0xFD,0x1F,0xB8,0xFF,0x00,0x00
};
#endif //_MGINCORE_RES
